| altNames | R Documentation |
Checks alternatenames column
altNames(gn, strings)
gn |
data frame(s), which will be accessed. |
strings |
character string vector with regular expressions to filter data. |
A list of two vectors, logical values and matched strings.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.