checkPath: Check path for downloaded data

View source: R/check_path.R

checkPathR Documentation

Check path for downloaded data

Description

This function checks the download path for the toponym package.

Usage

checkPath(toponym_path = NULL)

Arguments

toponym_path

character string. Path name for downloaded data. If not specified, this function will call toponymOptions() and try use the persistent path.

Details

If a path is provided using a function, this function checks it for validity. If no path is provided, this function retrieve the path from the .Rds file stored in the package directory and checks it for validity.

Value

Character string of the used path for downloaded data.


toponym documentation built on April 13, 2026, 5:06 p.m.