countryInfo: Country information

countryInfoR Documentation

Country information

Description

A data frame which lists all countries available in the geodata package and GeoNames data set. The first column lists the ISO2 codes, the second the ISO2 codes and the third one all country names in full length.

Usage

countryInfo

Format

An object of class data.frame with 249 rows and 3 columns.


toponym documentation built on April 13, 2026, 5:06 p.m.