| flanders_polygon | R Documentation |
A small data frame containing coordinates for the polygon framing Flanders. There is one column for the longitudes ('lons') and one for the latitudes ('lats'). The coordinates were retrieved from a personal polygon created with Google My Maps.
flanders_polygon
An object of class data.frame with 22 rows and 2 columns.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.