map_simple: Plots toponyms onto a map

View source: R/map_simple.R

map_simpleR Documentation

Plots toponyms onto a map

Description

This function generates a map plotting all locations in a given data frame. This function uses map data from the geodata package.

Usage

map_simple(mapdata)

Arguments

mapdata

list. A list passed down by mapper(). It contains at least longitudinal and latitudinal data and the path for downloaded data.

Details

This is an internal function which is only used by mapper().

Value

A plot.


toponym documentation built on April 13, 2026, 5:06 p.m.