poly: Transforms coordinates into a window

View source: R/poly.R

polyR Documentation

Transforms coordinates into a window

Description

This function transforms polygonal data into an object of class owin for spatstat.geom functions. If data points run clockwise, data will be reversed for owin function. It requires counterclockwise data.

Usage

poly(polygon)

Arguments

polygon

data frame, coordinates of the polygon.

Value

An object of class owin which is a polygonal window.


toponym documentation built on April 13, 2026, 5:06 p.m.