readFiles: Reads GeoNames data

View source: R/read_files.R

readFilesR Documentation

Reads GeoNames data

Description

This function reads toponym data for the package.

Usage

readFiles(countries, feat.class = "P", toponym_path = NULL)

Arguments

countries

character string vector with country designations (names or ISO-codes).

feat.class

character string vector. Selects data only of those feature classes (check http://download.geonames.org/export/dump/readme.txt for the list of all feature classes). By default, it is P.

toponym_path

character string. Path name for downloaded data.

Details

This function accesses the data saved by getData(), reads it as data frame and stores it in the package environment. Here is further information on the used column names. Parameter countries accepts all designations found in country(query = "country table").

Value

A data frame with GeoNames data.


toponym documentation built on April 13, 2026, 5:06 p.m.