save_path: Save path for downloaded data.

View source: R/save_path.R

save_pathR Documentation

Save path for downloaded data.

Description

This function saves the download path for the toponym package.

Usage

save_path(toponym_path, toponym_options)

Arguments

toponym_path

character string. Path name for downloaded data.

toponym_options

character string. Current path from .rds file.

Value

A character string indicating the current path for downloaded data.


toponym documentation built on April 13, 2026, 5:06 p.m.