| checkPath | R Documentation |
This function checks the download path for the toponym package.
checkPath(toponym_path = NULL)
toponym_path |
character string. Path name for downloaded data. If not specified, this function will call |
If a path is provided using a function, this function checks it for validity. If no path is provided, this function retrieve the path from the .Rds file stored in the package directory and checks it for validity.
Character string of the used path for downloaded data.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.