| countryInfo | R Documentation |
A data frame which lists all countries available in the geodata package and GeoNames data set.
The first column lists the ISO2 codes, the second the ISO2 codes and the third one all country names in full length.
countryInfo
An object of class data.frame with 249 rows and 3 columns.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.