| map_simple | R Documentation |
This function generates a map plotting all locations in a given data frame. This function uses map data from the geodata package.
map_simple(mapdata)
mapdata |
list. A list passed down by |
This is an internal function which is only used by mapper().
A plot.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.