| ortho | R Documentation |
This function retrieves all symbols used in country data.
ortho(countries, ...)
countries |
character string vector with country designations (names or ISO-codes). |
... |
Additional parameter:
|
Parameter countries accepts all designations found in country(query = "country table").
The default column is "alternatenames". Other columns of possible interest are "name" and "asciiname".
It outputs an ordered frequency table of all symbols used in a given column of the GeoNames data for one or more countries specified.
Parameter toponym_path accepts "pkgdir" for the package directory or a full, alternative path.
With toponymOptions(), users can specify the path for toponym and map data downloaded by this package across sessions. See help(toponymOptions).
The data used is downloaded by getData() and is accessible on the GeoNames download server.
A table with frequencies of all symbols.
## We recommend setting a persistent path for downloaded data by using toponymOptions()
## Users can always set the path manually when a function is used
## For illustration purposes,
## 1. the path is manually set each time
## 2. and wrapped in donttest because data will be downloaded in the following example:
ortho(countries = "MC", toponym_path = tempdir())
# returns a table with frequencies of all symbols
# in the "alternatenames" column for the Monaco data set
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.