| poly | R Documentation |
This function transforms polygonal data into an object of class owin for spatstat.geom functions.
If data points run clockwise, data will be reversed for owin function. It requires counterclockwise data.
poly(polygon)
polygon |
data frame, coordinates of the polygon. |
An object of class owin which is a polygonal window.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.