| readFiles | R Documentation |
This function reads toponym data for the package.
readFiles(countries, feat.class = "P", toponym_path = NULL)
countries |
character string vector with country designations (names or ISO-codes). |
feat.class |
character string vector. Selects data only of those feature classes (check http://download.geonames.org/export/dump/readme.txt for the list of all feature classes). By default, it is |
toponym_path |
character string. Path name for downloaded data. |
This function accesses the data saved by getData(), reads it as data frame and stores it in the package environment. Here is further information on the used column names.
Parameter countries accepts all designations found in country(query = "country table").
A data frame with GeoNames data.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.