| save_path | R Documentation |
This function saves the download path for the toponym package.
save_path(toponym_path, toponym_options)
toponym_path |
character string. Path name for downloaded data. |
toponym_options |
character string. Current path from .rds file. |
A character string indicating the current path for downloaded data.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.