| toponym | R Documentation |
A package to analyze and visualize toponym distributions.
The main functions are the following:
top returns selected toponyms.
country helps in navigating designations of countries and regions used by the package.
createPolygon lets users create a polygon by point-and-click or directly retrieve polygon data.
mapper plots data onto a map.
topComp compares toponym substrings in a polygon and in the remainder of a country (or countries).
topFreq retrieves most frequent toponym substrings.
topZtest lets users apply a Z-test on toponym distributions.
toponymOptions lets users modify settings for managing data.
For more detailed descriptions please read the respective documentation.
Maintainer: Lennart Chevallier mail@lchevallier.de (ORCID)
Authors:
Søren Wichmann wichmannsoeren@gmail.com (ORCID)
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.